==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/qt4_docking_notify/translations/qt4_docking_notify_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Notify</source>
        <translation>Powiadom</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Balonik ikony w zasobniku</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Czas zaniku</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n sekunda</numerusform>
            <numerusform>%n sekundy</numerusform>
            <numerusform>%n sekund</numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Ikona powiadomienia</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Treść</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation>Brak ikony</translation>
    </message>
</context>
<context>
    <name>Qt4NotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation>Konfiguracja wyglądu balonika nad ikoną w zasobniku</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation>%&amp;t - tytuł (np. Nowa wiadomość) %&amp;m - treść powiadomienia (np. Wiadomość od Jasia), %&amp;d - szczegóły (np. treść wiadomości),%&amp;i - ikona powiadomienia</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/qt4_docking_notify/translations/qt4_docking_notify_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Notify</source>
        <translation>Powiadom</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Balonik ikony w zasobniku</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Czas zaniku</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n sekunda</numerusform><numerusform>%n sekundy</numerusform><numerusform>%n sekund</numerusform></translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Ikona powiadomienia</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Treść</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation>Brak ikony</translation>
    </message>
</context>
<context>
    <name>Qt4NotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation>Konfiguruj</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation>Konfiguracja wyglądu balonika nad ikoną w zasobniku</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation>%&amp;t - tytuł (np. Nowa wiadomość) %&amp;m - treść powiadomienia (np. Wiadomość od Jasia), %&amp;d - szczegóły (np. treść wiadomości),%&amp;i - ikona powiadomienia</translation>
    </message>
</context>
</TS>
